#ifndef INCLUDED_NEWSTRING
#define INCLUDED_NEWSTRING

#if STDC_HEADERS
# include <string.h>
#else
# ifdef HAVE_STRING_H
#  include <string.h>
# else
#  ifdef HAVE_STRINGS_H
#   include <strings.h>
#  endif
# endif
# ifndef HAVE_STRCHR
#  define strchr index
#  define strrchr rindex
# endif
# ifndef HAVE_MEMCPY
#  define memcpy(d, s, n) bcopy((s), (d), (n))
#  define memmove(d, s, n) bcopy((s), (d), (n))
# endif
#endif

#ifndef HAVE_STRNCMP
# ifdef HAVE_MEMCMP
#  define strncmp(A, B, C) memcmp(A, B, C)
# else
#  define strncmp(A, B, C) bcmp(A, B, C)
# endif
#endif

#ifndef HAVE_STRCASECMP
# define strcasecmp(A, B) stricmp(A, B)
#endif

#endif
